@@ -1,6 +1,7 @@
 from __future__ import unicode_literals
 
 import os
+import shutil
 import subprocess
 from tempfile import NamedTemporaryFile
 
@@ -26,7 +27,7 @@ class Compiler(object):
     def compilers(self):
         return [to_class(compiler) for compiler in settings.COMPILERS]
 
-    def compile(self, paths, force=False):
+    def compile(self, paths, compiler_options={}, force=False):
         def _compile(input_path):
             for compiler in self.compilers:
                 compiler = compiler(verbose=self.verbose, storage=self.storage)
@@ -38,7 +39,8 @@ class Compiler(object):
                     outfile = compiler.output_path(infile, compiler.output_extension)
                     outdated = compiler.is_outdated(infile, outfile)
                     compiler.compile_file(infile, outfile,
-                                          outdated=outdated, force=force)
+                                          outdated=outdated, force=force,
+                                          **compiler_options)
 
                     return compiler.output_path(input_path, compiler.output_extension)
             else:
@@ -112,6 +114,9 @@ class SubProcessCompiler(CompilerBase):
             else:
                 argument_list.extend(flattening_arg)
 
+        # The first element in argument_list is the program that will be executed; if it is '', then
+        # a PermissionError will be raised. Thus empty arguments are filtered out from argument_list
+        argument_list = filter(None, argument_list)
         stdout = None
         try:
             # We always catch stdout in a file, but we may not have a use for it.
@@ -143,6 +148,6 @@ class SubProcessCompiler(CompilerBase):
             # Decide what to do with captured stdout.
             if stdout:
                 if stdout_captured:
-                    os.rename(stdout.name, os.path.join(cwd or os.curdir, stdout_captured))
+                    shutil.move(stdout.name, os.path.join(cwd or os.curdir, stdout_captured))
                 else:
                     os.remove(stdout.name)
