@@ -13,9 +13,9 @@ class SASSCompiler(SubProcessCompiler):
         return filename.endswith(('.scss', '.sass'))
 
     def compile_file(self, infile, outfile, outdated=False, force=False):
-        command = "%s %s %s %s" % (
-            settings.PIPELINE_SASS_BINARY,
-            settings.PIPELINE_SASS_ARGUMENTS,
+        command = (
+            settings.SASS_BINARY,
+            settings.SASS_ARGUMENTS,
             infile,
             outfile
         )
