@@ -1,7 +1,6 @@
 from __future__ import unicode_literals
 
 import gzip
-import tempfile
 
 from io import BytesIO
 
@@ -10,8 +9,6 @@ from django.contrib.staticfiles.utils import matches_patterns
 
 from django.core.files.base import File
 
-from pipeline.conf import settings
-
 
 class PipelineMixin(object):
     packing = True
@@ -42,7 +39,7 @@ class PipelineMixin(object):
             for name, hashed_name, processed in super_class.post_process(paths.copy(), dry_run, **options):
                 yield name, hashed_name, processed
 
-    def get_available_name(self, name):
+    def get_available_name(self, name, max_length=None):
         if self.exists(name):
             self.delete(name)
         return name
