@@ -2,12 +2,16 @@ from __future__ import unicode_literals
 
 from django.test import TestCase
 
+from pipeline.collector import default_collector
 from pipeline.packager import Packager, PackageNotFound
 
 from tests.utils import _
 
 
 class PackagerTest(TestCase):
+    def setUp(self):
+        default_collector.collect()
+
     def test_package_for(self):
         packager = Packager()
         packager.packages['js'] = packager.create_packages({
@@ -39,3 +43,6 @@ class PackagerTest(TestCase):
             }
         })
         self.assertEqual(packages['templates'].templates, [_('pipeline/templates/photo/list.jst')])
+
+    def tearDown(self):
+        default_collector.clear()
