@@ -6,7 +6,7 @@ from jinja2 import Environment, PackageLoader
 from django.template import Template, Context
 from django.test import TestCase
 
-from pipeline.templatetags.ext import PipelineExtension
+from pipeline.jinja2 import PipelineExtension
 
 from tests.utils import pipeline_settings
 
@@ -14,7 +14,7 @@ from tests.utils import pipeline_settings
 class JinjaTest(TestCase):
     def setUp(self):
         self.env = Environment(extensions=[PipelineExtension],
-            loader=PackageLoader('pipeline', 'templates'))
+                               loader=PackageLoader('pipeline', 'templates'))
 
     def test_no_package(self):
         template = self.env.from_string(u"""{% stylesheet "unknow" %}""")
@@ -26,10 +26,10 @@ class JinjaTest(TestCase):
         template = self.env.from_string(u"""{% stylesheet "screen" %}""")
         self.assertEqual(u'<link href="/static/screen.css" rel="stylesheet" type="text/css" />', template.render())
 
+    @pipeline_settings(PIPELINE_ENABLED=False)
     def test_package_css_disabled(self):
-        with pipeline_settings(PIPELINE_ENABLED=False):
-            template = self.env.from_string(u"""{% stylesheet "screen" %}""")
-            self.assertEqual(u'''<link href="/static/pipeline/css/first.css" rel="stylesheet" type="text/css" />
+        template = self.env.from_string(u"""{% stylesheet "screen" %}""")
+        self.assertEqual(u'''<link href="/static/pipeline/css/first.css" rel="stylesheet" type="text/css" />
 <link href="/static/pipeline/css/second.css" rel="stylesheet" type="text/css" />
 <link href="/static/pipeline/css/urls.css" rel="stylesheet" type="text/css" />''', template.render())
 
